<?php

if ( ! function_exists( 'sante_is_installed' ) ) {
	/**
	 * Function that checks if forward plugin installed
	 *
	 * @param string $plugin - plugin name
	 *
	 * @return bool
	 */
	function sante_is_installed( $plugin ) {
		
		switch ( $plugin ) {
			case 'framework';
				return class_exists( 'QodeFramework' );
				break;
			case 'core';
				return class_exists( 'SanteCore' );
				break;
			case 'woocommerce';
				return class_exists( 'WooCommerce' );
				break;
			case 'gutenberg-page';
				$current_screen = function_exists( 'get_current_screen' ) ? get_current_screen() : array();
				
				return method_exists( $current_screen, 'is_block_editor' ) && $current_screen->is_block_editor();
				break;
			case 'gutenberg-editor':
				return class_exists( 'WP_Block_Type' );
				break;
			default:
				return false;
		}
	}
}

if ( ! function_exists( 'sante_include_theme_is_installed' ) ) {
	/**
	 * Function that set case is installed element for framework functionality
	 *
	 * @param bool $installed
	 * @param string $plugin - plugin name
	 *
	 * @return bool
	 */
	function sante_include_theme_is_installed( $installed, $plugin ) {
		
		if ( $plugin === 'theme' ) {
			return class_exists( 'SanteHandler' );
		}
		
		return $installed;
	}
	
	add_filter( 'qode_framework_filter_is_plugin_installed', 'sante_include_theme_is_installed', 10, 2 );
}

if ( ! function_exists( 'sante_template_part' ) ) {
	/**
	 * Function that echo module template part.
	 *
	 * @param string $module name of the module from inc folder
	 * @param string $template full path of the template to load
	 * @param string $slug
	 * @param array  $params array of parameters to pass to template
	 */
	function sante_template_part( $module, $template, $slug = '', $params = array() ) {
		echo sante_get_template_part( $module, $template, $slug, $params );
	}
}

if ( ! function_exists( 'sante_get_template_part' ) ) {
	/**
	 * Function that load module template part.
	 *
	 * @param string $module name of the module from inc folder
	 * @param string $template full path of the template to load
	 * @param string $slug
	 * @param array  $params array of parameters to pass to template
	 *
	 * @return string - string containing html of template
	 */
	function sante_get_template_part( $module, $template, $slug = '', $params = array() ) {
		$available_characters = '/[^A-Za-z0-9\_\-\/]/';

		if ( is_scalar( $module ) ) {
			$module = preg_replace( $available_characters, '', $module );
		} else {
			$module = '';
		}

		if ( is_scalar( $template ) ) {
			$template = preg_replace( $available_characters, '', $template );
		} else {
			$template = '';
		}

		if ( is_scalar( $slug ) ) {
			$slug = preg_replace( $available_characters, '', $slug );
		} else {
			$slug = '';
		}

		// HTML Content from template.
		$html          = '';
		$template_path = SANTE_INC_ROOT_DIR . '/' . $module;

		$temp = $template_path . '/' . $template;

		// The array of parameters to pass to the template.
		if ( is_array( $params ) && count( $params ) ) {
			extract( $params, EXTR_SKIP ); // @codingStandardsIgnoreLine
		}

		$template = '';

		if ( ! empty( $temp ) ) {
			if ( ! empty( $slug ) ) {
				$template = "{$temp}-{$slug}.php";

				if ( ! file_exists( $template ) ) {
					$template = $temp . '.php';
				}
			} else {
				$template = $temp . '.php';
			}
		}

		if ( $template ) {
			ob_start();
			include $template; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
			$html = ob_get_clean();
		}

		return $html;
	}
}

if ( ! function_exists( 'sante_get_page_id' ) ) {
	/**
	 * Function that returns current page id
	 * Additional conditional is to check if current page is any wp archive page (archive, category, tag, date etc.) and returns -1
	 *
	 * @return int
	 */
	function sante_get_page_id() {
		$page_id = get_queried_object_id();
		
		if ( sante_is_wp_template() ) {
			$page_id = -1;
		}
		
		return apply_filters( 'sante_filter_page_id', $page_id );
	}
}

if ( ! function_exists( 'sante_is_wp_template' ) ) {
	/**
	 * Function that checks if current page default wp page
	 *
	 * @return bool
	 */
	function sante_is_wp_template() {
		return is_archive() || is_search() || is_404() || ( is_front_page() && is_home() );
	}
}

if ( ! function_exists( 'sante_get_ajax_status' ) ) {
	/**
	 * Function that return status from ajax functions
	 *
	 * @param string $status - success or error
	 * @param string $message - ajax message value
	 * @param string|array $data - returned value
	 * @param string $redirect - url address
	 */
	function sante_get_ajax_status( $status, $message, $data = null, $redirect = '' ) {
		$response = array(
			'status'   => esc_attr( $status ),
			'message'  => esc_html( $message ),
			'data'     => $data,
			'redirect' => ! empty( $redirect ) ? esc_url( $redirect ) : '',
		);
		
		$output = json_encode( $response );
		
		exit( $output );
	}
}

if ( ! function_exists( 'sante_get_button_element' ) ) {
	/**
	 * Function that returns button with provided params
	 *
	 * @param array $params - array of parameters
	 *
	 * @return string - string representing button html
	 */
	function sante_get_button_element( $params ) {
		if ( class_exists( 'SanteCoreButtonShortcode' ) ) {
			return SanteCoreButtonShortcode::call_shortcode( $params );
		} else {
			$link   = isset( $params['link'] ) ? $params['link'] : '#';
			$target = isset( $params['target'] ) ? $params['target'] : '_self';
			$text   = isset( $params['text'] ) ? $params['text'] : '';
			
			return '<a itemprop="url" class="qodef-theme-button" href="' . esc_url( $link ) . '" target="' . esc_attr( $target ) . '">' . esc_html( $text ) . '</a>';
		}
	}
}

if ( ! function_exists( 'sante_render_button_element' ) ) {
	/**
	 * Function that render button with provided params
	 *
	 * @param array $params - array of parameters
	 */
	function sante_render_button_element( $params ) {
		echo sante_get_button_element( $params );
	}
}

if ( ! function_exists( 'sante_class_attribute' ) ) {
	/**
	 * Function that render class attribute
	 *
	 * @param string|array $class
	 */
	function sante_class_attribute( $class ) {
		echo sante_get_class_attribute( $class );
	}
}

if ( ! function_exists( 'sante_get_class_attribute' ) ) {
	/**
	 * Function that return class attribute
	 *
	 * @param string|array $class
	 *
	 * @return string|mixed
	 */
	function sante_get_class_attribute( $class ) {
		$value = sante_is_installed( 'framework' ) ? qode_framework_get_class_attribute( $class ) : '';
		
		return $value;
	}
}

if ( ! function_exists( 'sante_get_post_value_through_levels' ) ) {
	/**
	 * Function that returns meta value if exists
	 *
	 * @param string $name name of option
	 * @param int    $post_id id of
	 *
	 * @return string value of option
	 */
	function sante_get_post_value_through_levels( $name, $post_id = null ) {
		return sante_is_installed( 'framework' ) && sante_is_installed( 'core' ) ? sante_core_get_post_value_through_levels( $name, $post_id ) : '';
	}
}

if ( ! function_exists( 'sante_get_space_value' ) ) {
	/**
	 * Function that returns spacing value based on selected option
	 *
	 * @param string $text_value - textual value of spacing
	 *
	 * @return int
	 */
	function sante_get_space_value( $text_value ) {
		return sante_is_installed( 'core' ) ? sante_core_get_space_value( $text_value ) : 0;
	}
}

if ( ! function_exists( 'sante_wp_kses_html' ) ) {
	/**
	 * Function that does escaping of specific html.
	 * It uses wp_kses function with predefined attributes array.
	 *
	 * @see wp_kses()
	 *
	 * @param string $type - type of html element
	 * @param string $content - string to escape
	 *
	 * @return string escaped output
	 */
	function sante_wp_kses_html( $type, $content ) {
		return sante_is_installed( 'framework' ) ? qode_framework_wp_kses_html( $type, $content ) : $content;
	}
}

if ( ! function_exists( 'sante_render_svg_icon' ) ) {
	/**
	 * Function that print svg html icon
	 *
	 * @param string $name - icon name
	 * @param string $class_name - custom html tag class name
	 */
	function sante_render_svg_icon( $name, $class_name = '' ) {
		echo sante_get_svg_icon( $name, $class_name );
	}
}

if ( ! function_exists( 'sante_get_svg_icon' ) ) {
	/**
	 * Returns svg html
	 *
	 * @param string $name - icon name
	 * @param string $class_name - custom html tag class name
	 *
	 * @return string|html
	 */
	function sante_get_svg_icon( $name, $class_name = '' ) {
		$html  = '';
		$class = isset( $class_name ) && ! empty( $class_name ) ?  'class="' . esc_attr( $class_name ) . '"' : '';
		
		switch ( $name ) {
			case 'menu':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="64px" height="64px" viewBox="0 0 64 64" enable-background="new 0 0 64 64" xml:space="preserve"><line x1="12" y1="21" x2="52" y2="21"/><line x1="12" y1="33" x2="52" y2="33"/><line x1="12" y1="45" x2="52" y2="45"/></svg>';
				break;
			case 'search':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32.24800109863281" height="32.24800109863281" viewBox="0 0 32.24800109863281 32.24800109863281"><g><path d="M 19,0C 11.82,0, 6,5.82, 6,13c0,3.090, 1.084,5.926, 2.884,8.158l-8.592,8.592c-0.54,0.54-0.54,1.418,0,1.958 c 0.54,0.54, 1.418,0.54, 1.958,0l 8.592-8.592C 13.074,24.916, 15.91,26, 19,26c 7.18,0, 13-5.82, 13-13S 26.18,0, 19,0z M 19,24 C 12.934,24, 8,19.066, 8,13S 12.934,2, 19,2S 30,6.934, 30,13S 25.066,24, 19,24z"/></g></svg>';
				break;
			case 'star':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 20.756,11.768L 15.856,1.84L 10.956,11.768L0,13.36L 7.928,21.088L 6.056,32L 15.856,26.848L 25.656,32L 23.784,21.088L 31.712,13.36 z"></path></g></svg>';
				break;
			case 'menu-arrow-right':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 13.8,24.196c 0.39,0.39, 1.024,0.39, 1.414,0l 6.486-6.486c 0.196-0.196, 0.294-0.454, 0.292-0.71 c0-0.258-0.096-0.514-0.292-0.71L 15.214,9.804c-0.39-0.39-1.024-0.39-1.414,0c-0.39,0.39-0.39,1.024,0,1.414L 19.582,17 L 13.8,22.782C 13.41,23.172, 13.41,23.806, 13.8,24.196z"></path></g></svg>';
				break;
			case 'slider-arrow-left':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 26 50.9" xml:space="preserve"><polyline points="25.6,0.4 0.7,25.5 25.6,50.6 "/></svg>';
				break;
			case 'slider-arrow-right':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 26 50.9" xml:space="preserve"><polyline points="0.4,50.6 25.3,25.5 0.4,0.4 "/></svg>';
				break;
			case 'pagination-arrow-left':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 12.3,17.71l 6.486,6.486c 0.39,0.39, 1.024,0.39, 1.414,0c 0.39-0.39, 0.39-1.024,0-1.414L 14.418,17 L 20.2,11.218c 0.39-0.39, 0.39-1.024,0-1.414c-0.39-0.39-1.024-0.39-1.414,0L 12.3,16.29C 12.104,16.486, 12.008,16.742, 12.008,17 C 12.008,17.258, 12.104,17.514, 12.3,17.71z"></path></g></svg>';
				break;
			case 'pagination-arrow-right':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 13.8,24.196c 0.39,0.39, 1.024,0.39, 1.414,0l 6.486-6.486c 0.196-0.196, 0.294-0.454, 0.292-0.71 c0-0.258-0.096-0.514-0.292-0.71L 15.214,9.804c-0.39-0.39-1.024-0.39-1.414,0c-0.39,0.39-0.39,1.024,0,1.414L 19.582,17 L 13.8,22.782C 13.41,23.172, 13.41,23.806, 13.8,24.196z"></path></g></svg>';
				break;
			case 'close':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 10.050,23.95c 0.39,0.39, 1.024,0.39, 1.414,0L 17,18.414l 5.536,5.536c 0.39,0.39, 1.024,0.39, 1.414,0 c 0.39-0.39, 0.39-1.024,0-1.414L 18.414,17l 5.536-5.536c 0.39-0.39, 0.39-1.024,0-1.414c-0.39-0.39-1.024-0.39-1.414,0 L 17,15.586L 11.464,10.050c-0.39-0.39-1.024-0.39-1.414,0c-0.39,0.39-0.39,1.024,0,1.414L 15.586,17l-5.536,5.536 C 9.66,22.926, 9.66,23.56, 10.050,23.95z"></path></g></svg>';
				break;
			case 'spinner':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" width="512" height="512" viewBox="0 0 512 512"><path d="M304 48c0 26.51-21.49 48-48 48s-48-21.49-48-48 21.49-48 48-48 48 21.49 48 48zm-48 368c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zm208-208c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zM96 256c0-26.51-21.49-48-48-48S0 229.49 0 256s21.49 48 48 48 48-21.49 48-48zm12.922 99.078c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.491-48-48-48zm294.156 0c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.49-48-48-48zM108.922 60.922c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.491-48-48-48z"></path></svg>';
				break;
			case 'link':
				$html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32.06999969482422" height="33.58000183105469" viewBox="0 0 32.06999969482422 33.58000183105469"><g><path d="M 7.54,15.77c 1.278,1.278, 3.158,1.726, 4.868,1.216L 2.96,7.54C 2.652,7.232, 2.49,6.786, 2.49,6.254 c0-0.88, 0.46-2.004, 1.070-2.614c 0.8-0.8, 2.97-1.686, 3.98-0.682l 9.446,9.448c 0.138-0.462, 0.208-0.942, 0.208-1.422 c0-1.304-0.506-2.526-1.424-3.446L 9.364,1.134C 7.44-0.79, 3.616-0.068, 1.734,1.814C 0.642,2.906-0.036,4.598-0.036,6.23 c0,1.268, 0.416,2.382, 1.17,3.136L 7.54,15.77zM 24.46,16.23c-1.278-1.278-3.158-1.726-4.868-1.216l 9.448,9.448c 0.308,0.308, 0.47,0.752, 0.47,1.286 c0,0.88-0.46,2.004-1.070,2.614c-0.8,0.8-2.97,1.686-3.98,0.682L 15.014,19.594c-0.138,0.462-0.208,0.942-0.208,1.422 c0,1.304, 0.506,2.526, 1.424,3.446l 6.404,6.404c 1.924,1.924, 5.748,1.202, 7.63-0.68c 1.092-1.092, 1.77-2.784, 1.77-4.416 c0-1.268-0.416-2.382-1.17-3.136L 24.46,16.23zM 9.164,9.162C 8.908,9.416, 8.768,9.756, 8.768,10.116s 0.14,0.698, 0.394,0.952l 11.768,11.77 c 0.526,0.524, 1.38,0.524, 1.906,0c 0.256-0.254, 0.394-0.594, 0.394-0.954s-0.14-0.698-0.394-0.952L 11.068,9.162 C 10.544,8.638, 9.688,8.638, 9.164,9.162z"></path></g></svg>';
				break;
            case 'preloader':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" width="109.665" height="109.835"><path fill="#68745C" d="M53.726 80.843a.908.908 0 01-.908-.908V32.743a.908.908 0 111.816 0v47.192a.907.907 0 01-.908.908z"/><path fill="#68745C" d="M53.254 40.023a.904.904 0 01-.557-.191l-4.247-3.304a.907.907 0 111.115-1.433l4.247 3.304a.907.907 0 01-.558 1.624zM53.254 44.742a.905.905 0 01-.544-.181l-7.186-5.39a.909.909 0 011.089-1.453l7.186 5.39a.909.909 0 01-.545 1.634zM53.254 50.051a.905.905 0 01-.544-.181l-8.371-6.279a.908.908 0 011.09-1.453l8.371 6.279a.908.908 0 01-.546 1.634zM53.254 55.36a.905.905 0 01-.544-.181l-9.791-7.343a.909.909 0 011.089-1.453l9.791 7.343a.909.909 0 01-.545 1.634zM53.254 60.67a.905.905 0 01-.544-.181l-10.383-7.787a.909.909 0 011.089-1.453l10.383 7.787a.909.909 0 01-.545 1.634zM53.254 65.979a.905.905 0 01-.544-.181L42.327 58.01a.908.908 0 011.09-1.453L53.8 64.344a.908.908 0 01-.546 1.635zM53.254 71.288a.905.905 0 01-.544-.181L42.327 63.32a.909.909 0 011.089-1.453l10.383 7.787a.909.909 0 01-.545 1.634zM53.254 76.598a.905.905 0 01-.544-.181L42.327 68.63a.909.909 0 011.089-1.453l10.383 7.787a.909.909 0 01-.545 1.634z"/><path fill="#68745C" d="M53.845 40.023a.906.906 0 01-.558-1.624l4.247-3.304a.908.908 0 111.115 1.433l-4.247 3.304a.91.91 0 01-.557.191zM53.845 44.742a.907.907 0 01-.545-1.634l7.186-5.39a.908.908 0 011.089 1.453l-7.186 5.39a.905.905 0 01-.544.181zM53.845 50.051a.908.908 0 01-.546-1.634l8.371-6.279a.908.908 0 011.09 1.453l-8.371 6.279a.905.905 0 01-.544.181zM53.845 55.36a.907.907 0 01-.545-1.634l9.791-7.343a.909.909 0 011.089 1.453l-9.791 7.343a.905.905 0 01-.544.181zM53.845 60.67a.907.907 0 01-.545-1.634l10.383-7.787a.909.909 0 011.089 1.453l-10.383 7.787a.905.905 0 01-.544.181zM53.845 65.979a.908.908 0 01-.546-1.634l10.383-7.787a.909.909 0 011.09 1.453l-10.383 7.787a.905.905 0 01-.544.181zM53.845 71.288a.907.907 0 01-.545-1.634l10.383-7.787a.909.909 0 011.089 1.453l-10.383 7.787a.905.905 0 01-.544.181zM53.845 76.598a.907.907 0 01-.545-1.634l10.383-7.787a.909.909 0 011.089 1.453l-10.383 7.787a.905.905 0 01-.544.181z"/><g><path fill="#68745C" d="M53.721 109.835C24.099 109.835 0 85.736 0 56.114c0-10.3 2.938-20.319 8.495-28.976l.926.595A52.422 52.422 0 001.1 56.114c0 29.016 23.606 52.622 52.622 52.622a52.403 52.403 0 0028.75-8.557l.602.921a53.507 53.507 0 01-29.353 8.735z"/><g fill="#68745C"><path d="M18.906 20.86l2.201-2.04.579.625-3.001 2.782-5.75-6.206.801-.742 5.17 5.581zM22.491 11.058c.565-.069 1.112.021 1.641.273s.993.657 1.393 1.217.632 1.129.696 1.708a2.93 2.93 0 01-.277 1.636c-.249.512-.63.952-1.144 1.319-.514.368-1.054.586-1.619.655-.565.07-1.112-.019-1.642-.265s-.995-.649-1.395-1.208c-.4-.56-.631-1.132-.695-1.716s.029-1.132.278-1.644c.249-.512.63-.952 1.145-1.319.514-.368 1.054-.586 1.619-.656zM20.7 13.34a1.988 1.988 0 00-.184 1.126c.046.415.225.84.536 1.276.307.43.649.733 1.027.911.377.178.752.242 1.125.192.372-.05.718-.189 1.037-.417.319-.228.562-.51.73-.846a1.98 1.98 0 00.183-1.126c-.045-.415-.222-.837-.529-1.267-.312-.436-.656-.743-1.034-.92-.377-.178-.752-.242-1.125-.192s-.718.189-1.037.417c-.318.228-.561.51-.729.846zM29.524 7.168a2.5 2.5 0 011.407.732l-.751-1.502.977-.488 2.945 5.893-.977.488-.751-1.503a2.489 2.489 0 01-.258 1.564c-.254.485-.667.87-1.24 1.156a2.99 2.99 0 01-1.578.333 2.828 2.828 0 01-1.484-.566c-.46-.338-.843-.815-1.151-1.431-.308-.615-.459-1.21-.456-1.784.004-.574.149-1.085.435-1.532s.69-.801 1.213-1.063c.573-.286 1.129-.385 1.669-.297zm-2.111 2.323c-.17.563-.087 1.182.249 1.854.336.673.781 1.11 1.333 1.313s1.129.153 1.731-.147c.386-.193.687-.455.901-.786.215-.331.327-.702.336-1.114.009-.411-.094-.832-.309-1.261a2.707 2.707 0 00-.826-1.009 2.046 2.046 0 00-1.092-.4 2.279 2.279 0 00-1.167.255c-.601.299-.986.731-1.156 1.295zM37.714 4.07c.519.173.942.49 1.27.949l-1.183-3.792 1.042-.325 2.644 8.477-1.042.325-.5-1.604c-.008.564-.177 1.065-.505 1.503s-.798.752-1.409.942c-.558.174-1.095.199-1.611.075-.516-.124-.974-.389-1.374-.797s-.702-.94-.907-1.597c-.205-.657-.259-1.268-.164-1.834.096-.566.321-1.047.675-1.442s.81-.68 1.368-.854c.611-.191 1.177-.199 1.696-.026zm-2.458 1.954c-.258.529-.275 1.152-.052 1.87.224.718.592 1.221 1.105 1.51.513.288 1.091.332 1.732.132.413-.129.751-.339 1.016-.631s.435-.641.51-1.045c.075-.404.041-.836-.102-1.294a2.719 2.719 0 00-.654-1.129c-.292-.294-.631-.484-1.014-.57s-.781-.064-1.193.064c-.64.2-1.089.565-1.348 1.093zM41.268.306c.109-.147.274-.243.494-.286.22-.043.408-.017.565.079s.255.241.294.437.003.369-.107.516c-.109.148-.274.244-.493.287s-.408.017-.565-.079a.627.627 0 01-.294-.438.625.625 0 01.106-.516zm1.525 2.165l1.268 6.465-1.071.21-1.268-6.465 1.071-.21zM50.353 2.185c.514.448.812 1.135.895 2.059l.34 3.813-1.088.096-.332-3.717c-.058-.653-.271-1.14-.636-1.461-.366-.32-.836-.456-1.41-.404-.598.053-1.059.29-1.382.708-.324.418-.453.998-.387 1.739l.311 3.478-1.088.097-.586-6.562 1.088-.097.139 1.554c.12-.548.379-.985.78-1.311.401-.325.88-.512 1.438-.562.765-.068 1.404.122 1.918.57zM57.703 2.137c.422.349.703.796.844 1.342l.11-1.676 1.089.072-.439 6.681c-.04.607-.203 1.137-.489 1.591-.287.454-.67.798-1.15 1.031-.48.233-1.028.33-1.643.289-.886-.058-1.595-.319-2.125-.783s-.848-1.064-.952-1.8l1.078.071c.099.447.317.809.656 1.083.338.275.788.431 1.346.467.591.039 1.092-.119 1.504-.472.412-.354.64-.87.685-1.548l.117-1.784c-.211.523-.548.93-1.012 1.22s-1.016.414-1.654.372a2.985 2.985 0 01-1.53-.509 2.82 2.82 0 01-.995-1.238c-.226-.523-.317-1.129-.271-1.815.045-.687.214-1.277.507-1.771a2.816 2.816 0 011.149-1.103c.473-.241 1-.343 1.583-.305.639.042 1.17.237 1.592.585zm-2.996.94c-.431.401-.671.976-.721 1.727-.05.75.113 1.353.488 1.806.375.454.898.703 1.568.747.431.028.823-.046 1.175-.223s.636-.441.852-.792c.216-.351.339-.765.371-1.244a2.707 2.707 0 00-.204-1.288 2.034 2.034 0 00-.741-.897 2.27 2.27 0 00-1.136-.369c-.67-.046-1.221.132-1.652.533zM70.345 10.446l2.792 1.096-.311.793-3.809-1.495 3.091-7.875 1.017.399-2.78 7.082zM80.766 9.443c.307.479.461 1.012.463 1.598s-.163 1.18-.494 1.782c-.332.603-.745 1.058-1.238 1.367a2.928 2.928 0 01-1.594.458c-.569-.002-1.131-.156-1.684-.461-.554-.305-.984-.697-1.292-1.176a2.973 2.973 0 01-.472-1.595c-.007-.584.155-1.177.486-1.78.332-.603.747-1.059 1.246-1.369a2.953 2.953 0 011.603-.46c.569.003 1.131.156 1.685.461s.984.696 1.291 1.175zm-2.832-.627a1.996 1.996 0 00-1.095.322c-.354.221-.661.566-.919 1.036-.254.462-.38.902-.377 1.32.003.417.108.783.314 1.097.206.314.481.565.824.754s.703.287 1.079.292c.375.006.74-.102 1.095-.322.354-.221.659-.562.913-1.025.258-.469.386-.913.382-1.33a1.982 1.982 0 00-.314-1.097c-.206-.314-.481-.566-.824-.755s-.703-.286-1.078-.292zM87.304 14.092a2.5 2.5 0 01-.051 1.584l1.029-1.328.863.669-4.036 5.207-.863-.669 1.029-1.328a2.503 2.503 0 01-1.522.445c-.547-.019-1.073-.225-1.579-.617-.461-.357-.789-.784-.983-1.278s-.238-1.022-.132-1.583c.105-.561.369-1.113.791-1.657.421-.543.892-.938 1.411-1.184s1.042-.336 1.569-.271 1.021.275 1.483.633c.506.394.836.852.991 1.377zm-3.009-.897c-.582.091-1.103.434-1.563 1.028-.46.595-.663 1.185-.605 1.771.057.585.352 1.084.883 1.496.341.265.708.422 1.099.472.391.05.774-.01 1.149-.18.375-.17.709-.445 1.003-.824s.478-.773.552-1.182a2.032 2.032 0 00-.113-1.157 2.278 2.278 0 00-.735-.942c-.532-.412-1.089-.573-1.67-.482zM93.628 20.102c.07.543-.03 1.062-.301 1.557l2.899-2.715.747.797-6.481 6.07-.747-.797 1.227-1.148c-.512.238-1.036.304-1.573.199s-1.024-.392-1.461-.859c-.399-.426-.656-.898-.769-1.417a2.812 2.812 0 01.12-1.583c.193-.537.541-1.041 1.043-1.511.502-.47 1.029-.785 1.58-.946.551-.16 1.083-.167 1.593-.02s.965.433 1.364.859c.436.466.69.971.759 1.514zm-2.829-1.362c-.588-.002-1.157.253-1.706.768-.549.514-.841 1.064-.877 1.652-.037.587.175 1.126.634 1.617.295.315.632.528 1.011.64a2.09 2.09 0 001.163.004c.396-.108.771-.327 1.121-.655a2.71 2.71 0 00.732-1.08c.137-.392.161-.778.072-1.161s-.282-.731-.577-1.046c-.46-.491-.984-.737-1.573-.739zM97.292 23.991l-5.266 3.959-.656-.873 5.266-3.959.656.873zm1.284-2.317c.181.034.338.141.473.32.134.179.193.36.176.543a.627.627 0 01-.266.455.621.621 0 01-.511.129c-.181-.034-.339-.141-.473-.32-.135-.179-.193-.36-.176-.543.017-.183.106-.335.266-.455s.33-.163.511-.129zM100.848 30.667c-.179.658-.667 1.225-1.462 1.703l-3.283 1.969-.562-.937 3.2-1.92c.563-.337.908-.741 1.037-1.21s.045-.951-.251-1.445c-.309-.514-.722-.826-1.24-.935-.518-.109-1.096.027-1.734.41l-2.995 1.796-.562-.937 5.649-3.389.562.936-1.337.803c.546-.132 1.052-.088 1.52.131s.845.568 1.133 1.048c.395.66.503 1.318.325 1.977zM104.085 37.265a2.505 2.505 0 01-.843 1.343l1.558-.628.408 1.013-6.21 2.504c-.564.228-1.113.311-1.646.25a2.768 2.768 0 01-1.428-.588c-.418-.332-.743-.783-.973-1.354-.333-.824-.404-1.575-.217-2.254.188-.68.591-1.226 1.209-1.639l.404 1.001c-.36.283-.59.637-.691 1.062s-.046.896.163 1.416c.221.549.581.932 1.078 1.15.498.218 1.062.2 1.692-.055l1.658-.669a2.498 2.498 0 01-1.539-.382c-.463-.292-.814-.735-1.053-1.328-.218-.542-.287-1.075-.205-1.6.082-.524.31-1.002.684-1.434s.88-.775 1.518-1.033 1.243-.361 1.815-.312c.572.05 1.069.235 1.492.557s.743.752.962 1.294c.241.592.294 1.155.164 1.686zm-2.147-2.291c-.548-.214-1.171-.181-1.868.1-.698.281-1.169.689-1.415 1.224s-.243 1.114.008 1.737c.162.4.398.721.711.962.313.24.674.382 1.083.423.41.042.837-.026 1.282-.206.445-.18.802-.427 1.071-.743.27-.316.432-.668.486-1.057s.002-.783-.16-1.184c-.25-.623-.65-1.041-1.198-1.256zM102.077 52.282l.223 2.992-.85.063-.304-4.081 8.437-.628.081 1.089-7.587.565zM107.512 61.214a2.928 2.928 0 01-1.234 1.114c-.527.257-1.133.368-1.82.332s-1.277-.208-1.77-.519a2.933 2.933 0 01-1.108-1.235c-.246-.514-.352-1.086-.319-1.717.033-.631.198-1.189.496-1.675.297-.485.707-.858 1.229-1.12s1.126-.374 1.813-.338 1.279.21 1.775.524a2.96 2.96 0 011.113 1.242c.246.513.352 1.085.32 1.717-.032.631-.198 1.19-.495 1.675zm-.67-2.822a1.984 1.984 0 00-.768-.845c-.354-.222-.797-.348-1.332-.375-.527-.027-.979.052-1.353.236a1.99 1.99 0 00-.851.761c-.193.322-.3.679-.32 1.071a2.27 2.27 0 00.207 1.098 2 2 0 00.767.845c.354.223.793.348 1.32.375.535.028.99-.051 1.365-.235.373-.185.656-.439.85-.761s.299-.68.32-1.071a2.266 2.266 0 00-.205-1.099zM106.182 69.116a2.506 2.506 0 01-1.448.645l1.644.347-.226 1.068-6.446-1.361.226-1.069 1.644.347c-.488-.283-.843-.675-1.064-1.175s-.266-1.064-.133-1.69c.121-.571.361-1.052.721-1.442.36-.39.816-.66 1.367-.809.55-.149 1.163-.153 1.835-.011.674.142 1.233.394 1.681.753.447.36.757.792.929 1.294s.198 1.039.077 1.611c-.133.626-.402 1.124-.807 1.492zm-.504-3.099c-.336-.484-.871-.803-1.607-.958-.735-.156-1.354-.08-1.856.227s-.823.789-.962 1.446c-.089.423-.071.821.054 1.195s.347.692.663.956.709.444 1.179.543.904.093 1.304-.019.73-.314.993-.606c.262-.292.438-.65.526-1.072.139-.658.041-1.229-.294-1.712zM103.51 77.458a2.505 2.505 0 01-1.533.404l3.705 1.434-.395 1.019-8.281-3.207.395-1.018 1.566.606a2.498 2.498 0 01-.861-1.331c-.138-.53-.091-1.093.14-1.69.211-.544.525-.98.944-1.307a2.812 2.812 0 011.479-.579c.567-.059 1.172.036 1.813.284s1.153.586 1.538 1.014c.383.427.619.903.709 1.426a2.996 2.996 0 01-.184 1.602c-.23.596-.576 1.044-1.035 1.343zm0-3.14c-.253-.532-.73-.933-1.431-1.205-.701-.271-1.325-.296-1.87-.074-.545.222-.938.646-1.181 1.273a2.248 2.248 0 00-.139 1.188c.063.389.23.739.501 1.049.27.311.629.553 1.076.726.448.173.878.237 1.291.19a2.043 2.043 0 001.077-.438c.305-.247.536-.571.691-.974.245-.625.239-1.204-.015-1.735zM101.603 82.424l-5.85-3.03.502-.97 5.85 3.03-.502.97zm2.644.153c.047.178.02.366-.084.565-.103.199-.24.33-.413.394a.628.628 0 01-.525-.042c-.178-.092-.29-.227-.338-.405s-.02-.366.083-.565c.104-.199.241-.33.414-.394a.632.632 0 01.525.042c.177.093.29.227.338.405zM97.114 88.533c-.67.123-1.393-.07-2.168-.581l-3.196-2.107.601-.912 3.116 2.054c.548.361 1.061.499 1.54.412.479-.087.876-.371 1.194-.852.33-.501.432-1.008.307-1.522-.126-.514-.5-.976-1.121-1.386l-2.916-1.922.601-.912 5.5 3.626-.601.912-1.302-.859c.354.435.535.911.54 1.427.005.516-.147 1.007-.455 1.475-.422.642-.969 1.024-1.64 1.147zM92.586 94.295a2.497 2.497 0 01-1.575-.177l1.242 1.131-.735.808-4.952-4.507c-.449-.409-.762-.867-.939-1.375a2.766 2.766 0 01-.089-1.542c.117-.521.383-1.009.798-1.464.598-.657 1.244-1.048 1.937-1.174.694-.126 1.361 0 2.001.377l-.727.798a1.87 1.87 0 00-1.256-.162c-.426.093-.828.347-1.205.762-.398.438-.587.928-.568 1.471.02.542.281 1.043.784 1.5l1.322 1.204a2.502 2.502 0 01-.324-1.552c.063-.543.309-1.052.74-1.525a2.985 2.985 0 011.352-.879c.508-.154 1.038-.157 1.588-.007s1.081.456 1.589.919c.509.463.865.963 1.068 1.5.204.537.252 1.065.147 1.586-.106.52-.355.996-.749 1.428-.43.474-.913.767-1.449.88zm1.133-2.928c-.045-.587-.345-1.133-.901-1.64s-1.128-.754-1.717-.743c-.588.01-1.109.264-1.561.761a2.236 2.236 0 00-.558 1.059c-.081.386-.052.772.088 1.159.14.387.387.742.742 1.065s.733.538 1.135.643c.401.106.789.099 1.163-.021.374-.12.706-.339.997-.659.452-.495.656-1.037.612-1.624z"/></g></g></svg>';
                break;
		}
		
		return $html;
	}
}

if ( ! function_exists( 'sante_theme_get_svg_icon' ) ) {
    /**
     * Returns svg html
     *
     * @param string $name - icon name
     * @param string $class_name - custom html tag class name
     *
     * @return string|html
     */
    function sante_theme_get_svg_icon( $name, $class_name = '' ) {
        $html  = '';
        $class = isset( $class_name ) && ! empty( $class_name ) ? 'class="' . esc_attr( $class_name ) . '"' : '';

        switch ( $name ) {
            case 'menu':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" width="64px" height="64px" viewBox="0 0 64 64" enable-background="new 0 0 64 64" xml:space="preserve"><line x1="12" y1="21" x2="52" y2="21"/><line x1="12" y1="33" x2="52" y2="33"/><line x1="12" y1="45" x2="52" y2="45"/></svg>';
                break;
            case 'search':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="20" height="20" viewBox="0 0 20 20"><path d="M18.869 19.162l-5.943-6.484c1.339-1.401 2.075-3.233 2.075-5.178 0-2.003-0.78-3.887-2.197-5.303s-3.3-2.197-5.303-2.197-3.887 0.78-5.303 2.197-2.197 3.3-2.197 5.303 0.78 3.887 2.197 5.303 3.3 2.197 5.303 2.197c1.726 0 3.362-0.579 4.688-1.645l5.943 6.483c0.099 0.108 0.233 0.162 0.369 0.162 0.121 0 0.242-0.043 0.338-0.131 0.204-0.187 0.217-0.503 0.031-0.706zM1 7.5c0-3.584 2.916-6.5 6.5-6.5s6.5 2.916 6.5 6.5-2.916 6.5-6.5 6.5-6.5-2.916-6.5-6.5z"></path></svg>';
                break;
            case 'star':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 20.756,11.768L 15.856,1.84L 10.956,11.768L0,13.36L 7.928,21.088L 6.056,32L 15.856,26.848L 25.656,32L 23.784,21.088L 31.712,13.36 z"></path></g></svg>';
                break;
            case 'menu-arrow-right':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 13.8,24.196c 0.39,0.39, 1.024,0.39, 1.414,0l 6.486-6.486c 0.196-0.196, 0.294-0.454, 0.292-0.71 c0-0.258-0.096-0.514-0.292-0.71L 15.214,9.804c-0.39-0.39-1.024-0.39-1.414,0c-0.39,0.39-0.39,1.024,0,1.414L 19.582,17 L 13.8,22.782C 13.41,23.172, 13.41,23.806, 13.8,24.196z"></path></g></svg>';
                break;
            case 'slider-arrow-left':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 26 50.9" xml:space="preserve"><polyline points="25.6,0.4 0.7,25.5 25.6,50.6 "/></svg>';
                break;
            case 'slider-arrow-right':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 26 50.9" xml:space="preserve"><polyline points="0.4,50.6 25.3,25.5 0.4,0.4 "/></svg>';
                break;
            case 'pagination-arrow-left':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 12.3,17.71l 6.486,6.486c 0.39,0.39, 1.024,0.39, 1.414,0c 0.39-0.39, 0.39-1.024,0-1.414L 14.418,17 L 20.2,11.218c 0.39-0.39, 0.39-1.024,0-1.414c-0.39-0.39-1.024-0.39-1.414,0L 12.3,16.29C 12.104,16.486, 12.008,16.742, 12.008,17 C 12.008,17.258, 12.104,17.514, 12.3,17.71z"></path></g></svg>';
                break;
            case 'pagination-arrow-right':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 13.8,24.196c 0.39,0.39, 1.024,0.39, 1.414,0l 6.486-6.486c 0.196-0.196, 0.294-0.454, 0.292-0.71 c0-0.258-0.096-0.514-0.292-0.71L 15.214,9.804c-0.39-0.39-1.024-0.39-1.414,0c-0.39,0.39-0.39,1.024,0,1.414L 19.582,17 L 13.8,22.782C 13.41,23.172, 13.41,23.806, 13.8,24.196z"></path></g></svg>';
                break;
            case 'close':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="32" viewBox="0 0 32 32"><g><path d="M 10.050,23.95c 0.39,0.39, 1.024,0.39, 1.414,0L 17,18.414l 5.536,5.536c 0.39,0.39, 1.024,0.39, 1.414,0 c 0.39-0.39, 0.39-1.024,0-1.414L 18.414,17l 5.536-5.536c 0.39-0.39, 0.39-1.024,0-1.414c-0.39-0.39-1.024-0.39-1.414,0 L 17,15.586L 11.464,10.050c-0.39-0.39-1.024-0.39-1.414,0c-0.39,0.39-0.39,1.024,0,1.414L 15.586,17l-5.536,5.536 C 9.66,22.926, 9.66,23.56, 10.050,23.95z"></path></g></svg>';
                break;
            case 'spinner':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" width="512" height="512" viewBox="0 0 512 512"><path d="M304 48c0 26.51-21.49 48-48 48s-48-21.49-48-48 21.49-48 48-48 48 21.49 48 48zm-48 368c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zm208-208c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.49-48-48-48zM96 256c0-26.51-21.49-48-48-48S0 229.49 0 256s21.49 48 48 48 48-21.49 48-48zm12.922 99.078c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.491-48-48-48zm294.156 0c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48c0-26.509-21.49-48-48-48zM108.922 60.922c-26.51 0-48 21.49-48 48s21.49 48 48 48 48-21.49 48-48-21.491-48-48-48z"></path></svg>';
                break;
            case 'link':
                $html = '<svg ' . $class . ' xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32.06999969482422" height="33.58000183105469" viewBox="0 0 32.06999969482422 33.58000183105469"><g><path d="M 7.54,15.77c 1.278,1.278, 3.158,1.726, 4.868,1.216L 2.96,7.54C 2.652,7.232, 2.49,6.786, 2.49,6.254 c0-0.88, 0.46-2.004, 1.070-2.614c 0.8-0.8, 2.97-1.686, 3.98-0.682l 9.446,9.448c 0.138-0.462, 0.208-0.942, 0.208-1.422 c0-1.304-0.506-2.526-1.424-3.446L 9.364,1.134C 7.44-0.79, 3.616-0.068, 1.734,1.814C 0.642,2.906-0.036,4.598-0.036,6.23 c0,1.268, 0.416,2.382, 1.17,3.136L 7.54,15.77zM 24.46,16.23c-1.278-1.278-3.158-1.726-4.868-1.216l 9.448,9.448c 0.308,0.308, 0.47,0.752, 0.47,1.286 c0,0.88-0.46,2.004-1.070,2.614c-0.8,0.8-2.97,1.686-3.98,0.682L 15.014,19.594c-0.138,0.462-0.208,0.942-0.208,1.422 c0,1.304, 0.506,2.526, 1.424,3.446l 6.404,6.404c 1.924,1.924, 5.748,1.202, 7.63-0.68c 1.092-1.092, 1.77-2.784, 1.77-4.416 c0-1.268-0.416-2.382-1.17-3.136L 24.46,16.23zM 9.164,9.162C 8.908,9.416, 8.768,9.756, 8.768,10.116s 0.14,0.698, 0.394,0.952l 11.768,11.77 c 0.526,0.524, 1.38,0.524, 1.906,0c 0.256-0.254, 0.394-0.594, 0.394-0.954s-0.14-0.698-0.394-0.952L 11.068,9.162 C 10.544,8.638, 9.688,8.638, 9.164,9.162z"></path></g></svg>';
                break;
        }

        return apply_filters( 'sante_filter_svg_icon', $html, $name );
    }
}

if ( ! function_exists( 'sante_theme_get_module_part' ) ) {
    /**
     * Function that returns inputted module
     *
     * @param string $module name of the module
     *
     * @return string
     */
    function sante_theme_get_module_part( $module ) {
        return $module;
    }
}
if ( ! function_exists( 'sante_escape_title_tag' ) ) {
	/**
	 * Function that escape title tag variable for modules
	 *
	 * @param string $title_tag
	 *
	 * @return string
	 */
	function sante_escape_title_tag( $title_tag ) {
		$allowed_tags = array(
			'h1',
			'h2',
			'h3',
			'h4',
			'h5',
			'h6',
			'p',
			'span',
			'ul',
			'ol',
			'div',
		);

		$escaped_title_tag = '';
		$title_tag         = strtolower( sanitize_key( $title_tag ) );

		if ( in_array( $title_tag, $allowed_tags, true ) ) {
			$escaped_title_tag = $title_tag;
		}

		return $escaped_title_tag;
	}
}
